==> mailjet-client-4.1.1-sources.jar: com/mailjet/client/resource/Messagesentstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Messagesentstatistics {

    public static Resource resource = new Resource("messagesentstatistics", "");

	public static String ARRIVALTS = "ArrivalTs";
	public static String BLOCKED = "Blocked";
	public static String BOUNCE = "Bounce";
	public static String BOUNCEDATE = "BounceDate";
	public static String BOUNCEREASON = "BounceReason";
	public static String CAMPAIGN = "Campaign";
	public static String CLICK = "Click";
	public static String CNTRECIPIENTS = "CntRecipients";
	public static String COMPLAINTDATE = "ComplaintDate";
	public static String CONTACT = "Contact";
	public static String DETAILS = "Details";
	public static String FBLSOURCE = "FBLSource";
	public static String MESSAGEID = "MessageID";
	public static String OPEN = "Open";
	public static String QUEUED = "Queued";
	public static String SENT = "Sent";
	public static String SPAM = "Spam";
	public static String STATE = "State";
	public static String STATEPERMANENT = "StatePermanent";
	public static String STATUS = "Status";
	public static String TOEMAIL = "ToEmail";
	public static String UNSUB = "Unsub";
	public static String ALLMESSAGES = "AllMessages";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACTSLIST = "ContactsList";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String CUSTOMID = "CustomID";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String RAWDATA = "RawData";
	public static String SHOWEXTRADATA = "ShowExtraData";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-4.2.1-sources.jar: com/mailjet/client/resource/Messagesentstatistics.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 * This endpoint will be deprecated as of 1st of july 2018. We advise to implement /statcounters endpoint instead.
 * 
 * @author Guillaume Badi
 */
@Deprecated
public class Messagesentstatistics {

    public static Resource resource = new Resource("messagesentstatistics", "");

	public static String ARRIVALTS = "ArrivalTs";
	public static String BLOCKED = "Blocked";
	public static String BOUNCE = "Bounce";
	public static String BOUNCEDATE = "BounceDate";
	public static String BOUNCEREASON = "BounceReason";
	public static String CAMPAIGN = "Campaign";
	public static String CLICK = "Click";
	public static String CNTRECIPIENTS = "CntRecipients";
	public static String COMPLAINTDATE = "ComplaintDate";
	public static String CONTACT = "Contact";
	public static String DETAILS = "Details";
	public static String FBLSOURCE = "FBLSource";
	public static String MESSAGEID = "MessageID";
	public static String OPEN = "Open";
	public static String QUEUED = "Queued";
	public static String SENT = "Sent";
	public static String SPAM = "Spam";
	public static String STATE = "State";
	public static String STATEPERMANENT = "StatePermanent";
	public static String STATUS = "Status";
	public static String TOEMAIL = "ToEmail";
	public static String UNSUB = "Unsub";
	public static String ALLMESSAGES = "AllMessages";
	public static String CAMPAIGNID = "CampaignID";
	public static String CAMPAIGNSTATUS = "CampaignStatus";
	public static String CONTACTSLIST = "ContactsList";
	public static String CUSTOMCAMPAIGN = "CustomCampaign";
	public static String CUSTOMID = "CustomID";
	public static String FROM = "From";
	public static String FROMDOMAIN = "FromDomain";
	public static String FROMID = "FromID";
	public static String FROMTS = "FromTS";
	public static String FROMTYPE = "FromType";
	public static String ISDELETED = "IsDeleted";
	public static String ISNEWSLETTERTOOL = "IsNewsletterTool";
	public static String ISSTARRED = "IsStarred";
	public static String MESSAGESTATUS = "MessageStatus";
	public static String PERIOD = "Period";
	public static String RAWDATA = "RawData";
	public static String SHOWEXTRADATA = "ShowExtraData";
	public static String TOTS = "ToTS";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}
